'''
__init__:
logo_allenlib():a logo of allenlib
computer_os:
dfrgui():open dfrgui
repairdisk(a):repair a disk
cleanmgr():clean the computer
message:
info(t,m):show info t:title m:message
warning(t,m):show warning t:title m:message
error(t,m):show error t:title m:message
ask(t,m):ask t:title m:message
ok(t,m):ask ok t:title m:message
yes(t,m):ask yes t:title m:message
retry(t,m):ask retry t:title m:message
ync(t,m):ask ync t:title m:message
printfun:
printfun(a):print fun a
raise:
raise(a):raise Exception(a)
speak:
speak(a):speak a
translate(a):translate a
print_load:
progess_bar(title,range):bar for linux
progess_bar_win(title,range):bar for windows
simplepygame:
it is simple than pygame,but it is only a pygame tool!
font(filename,size):set font
text(text,colorlist,bgcolor=None):show text
update():update
isquit():is quit?
autoquit():quit
quitis():auto isquit autoquit
quitwhile():quit is for while ...:
bgmsc:play background music
msc():sound value
playmsc(msc):msc() + autoplay
nobgm():stop background music
'''
def logo_allenlib():
    print('allenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib\nallenlib')